@@ -61,7 +61,7 @@ def croshell(
             print("Streamlit viewer is not yet implemented in this version.")
             return None
         file_obj = PathExtended(str(path).lstrip()).expanduser().absolute()
-        program = lambda_to_python_script(lambda: get_read_data_pycode(path=str(file_obj)), in_global=True)
+        program = lambda_to_python_script(lambda: get_read_data_pycode(path=str(file_obj)), in_global=True, import_module=False)
         text = f"📄 Reading data from: {file_obj.name}"
         console.print(Panel(text, title="[bold blue]Info[/bold blue]"))
     else:  # if nothing is specified, then run in interactive mode.
@@ -91,7 +91,7 @@ def croshell(
     pyfile.parent.mkdir(parents=True, exist_ok=True)
 
     title = "Reading Data"
-    def_code = lambda_to_python_script(lambda: code(path=str(pyfile), title=title), in_global=False)
+    def_code = lambda_to_python_script(lambda: code(path=str(pyfile), title=title), in_global=False, import_module=False)
     # print(def_code)
     python_program = preprogram + "\n\n" + def_code + program
     pyfile.write_text(python_program, encoding="utf-8")
@@ -158,8 +158,15 @@ code --new-window {str(pyfile)}
         # --python 3.14
         fire_line = f"uv run {ve_line} {interpreter} {interactivity} {profile} {str(pyfile)}"
 
-    from machineconfig.utils.code import run_shell_script
-    run_shell_script(fire_line, clean_env=False)
+    import os
+    program_path_maybe = os.environ.get("OP_PROGRAM_PATH", None)
+    if program_path_maybe is not None:
+        program_path_obj = PathExtended(program_path_maybe)
+        program_path_obj.parent.mkdir(parents=True, exist_ok=True)
+        program_path_obj.write_text(data=fire_line, encoding="utf-8")
+    else:
+        from machineconfig.utils.code import run_shell_script
+        run_shell_script(fire_line, clean_env=False)
 
 
 def main() -> None:
