@@ -1,4 +1,15 @@
 #!/bin/bash
+# Record script start time for runtime measurement
+# _START_TIME_NS=$(date +%s%N)
+# _show_elapsed() {
+#     local _end_ns _elapsed_ns _secs _ms
+#     _end_ns=$(date +%s%N)
+#     _elapsed_ns=$((_end_ns - _START_TIME_NS))
+#     _secs=$((_elapsed_ns / 1000000000))
+#     _ms=$((_elapsed_ns / 1000000 % 1000))
+#     printf "Script runtime: %d.%03d seconds\n" "$_secs" "$_ms"
+# }
+
 # 🛠️ Bash Shell Configuration and Initialization
 
 add_to_path_if_not_already() {
@@ -41,6 +52,7 @@ alias s=sessions
 alias ff=ftpx
 alias f=fire
 alias r=croshell
+alias u=utils
 
 # alias gcs='gh copilot suggest -t shell'
 # alias gcg='gh copilot suggest -t git'
@@ -74,3 +86,6 @@ eval "$(starship init bash)"
 # from https://github.com/cantino/mcfly
 eval "$(mcfly init bash)"
 
+# Show elapsed runtime
+# _show_elapsed
+
