@@ -1,8 +1,5 @@
 
-import atexit
-# import platform
 from typing import Any, Optional, Callable
-import subprocess
 from machineconfig.utils.accessories import randstr
 from machineconfig.utils.path_extended import PathExtended
 from pathlib import Path
@@ -37,7 +34,7 @@ def get_uv_command_executing_python_script(python_script: str, uv_with: Optional
     else:
         uv_project_dir_arg = ""
     from machineconfig.utils.meta import lambda_to_python_script
-    print_code_string = lambda_to_python_script(lambda: print_code(code=python_script, lexer="python", desc="Temporary Python Script", subtitle="Executing via shell script"), in_global=True)
+    print_code_string = lambda_to_python_script(lambda: print_code(code=python_script, lexer="python", desc="Temporary Python Script", subtitle="Executing via shell script"), in_global=True, import_module=False)
     python_file.write_text(print_code_string + "\n" + python_script, encoding="utf-8")
     shell_script = f"""uv run {uv_with_arg} {uv_project_dir_arg}  {str(python_file)} """
     return shell_script, python_file
@@ -45,7 +42,7 @@ def get_uv_command_executing_python_script(python_script: str, uv_with: Optional
 
 def run_lambda_function(lmb: Callable[[], Any], uv_with: Optional[list[str]], uv_project_dir: Optional[str]) -> None:
     from machineconfig.utils.meta import lambda_to_python_script
-    code = lambda_to_python_script(lmb, in_global=True)
+    code = lambda_to_python_script(lmb, in_global=True, import_module=False)
     uv_command, _py_file = get_uv_command_executing_python_script(python_script=code, uv_with=uv_with, uv_project_dir=uv_project_dir)
     run_shell_script(uv_command)
 
@@ -66,7 +63,6 @@ def run_shell_script(script: str, display_script: bool = True, clean_env: bool =
     with tempfile.NamedTemporaryFile(mode='w', suffix=suffix, delete=False, encoding='utf-8') as temp_file:
         temp_file.write(script)
         temp_script_path = PathExtended(temp_file.name)
-
     console = Console()
     if display_script:
         from rich.syntax import Syntax
@@ -92,37 +88,12 @@ def run_shell_script(script: str, display_script: bool = True, clean_env: bool =
     return proc
 
 
-def run_shell_script_after_exit(script: str, display_script: bool = True) -> None:
-    import platform
-    from rich.console import Console
-    from rich.panel import Panel
-    from rich.syntax import Syntax
-
-    console = Console()
-    def execute_script_at_exit() -> None:
-        if platform.system() == "Windows":
-            suffix = ".ps1"
-            lexer = "powershell"
-        else:
-            suffix = ".sh"
-            lexer = "bash"
-        
-        script_path = PathExtended.tmp().joinpath("tmp_scripts", "exit", randstr() + suffix)
-        script_path.parent.mkdir(parents=True, exist_ok=True)
-        script_path.write_text(script, encoding="utf-8")
-        
-        if display_script:
-            console.print(Panel(Syntax(code=script, lexer=lexer), title=f"📄 Exit script @ {script_path}", subtitle="Running at exit"), style="bold yellow")
-        
-        if platform.system() != "Windows":
-            script_path.chmod(0o755)
-        
-        if platform.system() == "Windows":
-            subprocess.run(["powershell", "-ExecutionPolicy", "Bypass", "-NoProfile", "-File", str(script_path)], check=False)
-        else:
-            subprocess.run(["bash", str(script_path)], check=False)
-        
-        script_path.unlink(missing_ok=True)
-    
-    atexit.register(execute_script_at_exit)
-
+def exit_then_run_shell_script(command: str):
+    import os
+    op_program_path = os.environ.get("OP_PROGRAM_PATH", None)
+    if op_program_path is not None:
+        op_program_path = PathExtended(op_program_path)
+        op_program_path.parent.mkdir(parents=True, exist_ok=True)
+        op_program_path.write_text(command, encoding="utf-8")
+    else:
+        run_shell_script(command)
