@@ -21,7 +21,7 @@ class Read:
             if "type object 'Read' has no attribute" not in str(err): raise AttributeError(err) from err
             if suffix in ('eps', 'jpg', 'jpeg', 'pdf', 'pgf', 'png', 'ps', 'raw', 'rgba', 'svg', 'svgz', 'tif', 'tiff'):
                 import matplotlib.pyplot as pyplot
-                return pyplot.imread(path, **kwargs)  # from: plt.gcf().canvas.get_supported_filetypes().keys():
+                return pyplot.imread(str(path), **kwargs)  # from: plt.gcf().canvas.get_supported_filetypes().keys():
             if suffix == "parquet":
                 import polars as pl
                 return pl.read_parquet(path, **kwargs)
@@ -37,17 +37,11 @@ class Read:
                 raise ImportError(err) from err2
     @staticmethod
     def json(path: 'Path', r: bool = False, **kwargs: Any) -> Any:  # return could be list or dict etc
-        import json
-        try:
-            mydict = json.loads(Path(path).read_text(encoding='utf-8'), **kwargs)
-        except Exception:
-            import pyjson5
-            mydict = pyjson5.loads(Path(path).read_text(encoding='utf-8'), **kwargs)  # file has C-style comments.
-        _ = r
-        return mydict
+        from machineconfig.utils.io import read_json
+        return read_json(path, r=r, **kwargs)
     @staticmethod
     def yaml(path: 'Path', r: bool = False) -> Any:  # return could be list or dict etc
-        import yaml  # type: ignore
+        import yaml
         with open(str(path), "r", encoding="utf-8") as file:
             mydict = yaml.load(file, Loader=yaml.FullLoader)
         _ = r
